#!/bin/perl -w
use strict;
use warnings;



sub help{
        if(grep {$_ eq "-h"} @ARGV){
                print "#########################################################################################################################\n\n";
                print "   This script can be used to select MAAs according to the block's identity and min_length from MAAs-15.maf \n";
                print "   Usage: perl maf_parse.pl identity_cut length_cut output_label <1: output_fasta; 2: output_table>\n";
                print "          identity_cut: Indicating a [0,1] number which determines the at least ratio of identical bases \n";
                print "                    accross all 15 species in one block with cucucmber as reference. Default: 0 \n";
                print "          length_cut: Indicating the minimal length of blocks with cucumber as reference. Default: 1 \n";
                print "          output_label: 1:len_identity.maf, 2:len_identity.fasta, 3:len_identity.table\n";
                print " 		 			   Columns in table: MAAs-ID species chromosome start end strand aligned_seq\n";
                print "#########################################################################################################################\n\n";
        }
}

&help();


die  "Maf_parse_Version 1.0\t2017-06-09;\nUsage: $0 <maf_file, identity_cut, length_cut, out_label>[out(1:len_identity.maf, 2:len_identity.fasta, 3:len_identity.table)]\n" unless $#ARGV > 1;
my($maf_file, $identity_cut, $len_cut, $out_label)=@ARGV;
if (!defined($identity_cut)){$identity_cut=0};
if (!defined($len_cut)){$len_cut=1};

my %maf_hash; ### key: block_id, value: @lines
my (%Cucumber, %Cucu_melo, %Water_melo, %Malus_dome, %Glyc_max, %Popu_tr, %Citrus, %Brass_ra, %Arab_ly, %Arab_th, %Viti_vi, %Sola_tu, %Oryza_brach, %Brach, %Seta_ti);
&collect_maf_hash($maf_file);
&collect_spec_hash(\%maf_hash);
&output_maf($identity_cut,$len_cut,$out_label);



sub output_maf{ 
	my ($identity_cut, $len_cut, $out_label)=@_;
	foreach my $id(sort keys%maf_hash){
			my $Cucumber_seq=(split /\s+/, $Cucumber{$id})[6];
 			my $Cucu_melo_seq=(split /\s+/, $Cucu_melo{$id})[6];
 			my $Water_melo_seq=(split /\s+/, $Water_melo{$id})[6];
			my $Malus_dome_seq=(split /\s+/, $Malus_dome{$id})[6];
			my $Glyc_max_seq=(split /\s+/, $Glyc_max{$id})[6];
			my $Popu_tr_seq=(split /\s+/, $Popu_tr{$id})[6];
			my $Citrus_seq=(split /\s+/, $Citrus{$id})[6];
			my $Brass_ra_seq=(split /\s+/, $Brass_ra{$id})[6];
			my $Arab_ly_seq=(split /\s+/, $Arab_ly{$id})[6];
			my $Arab_th_seq=(split /\s+/, $Arab_th{$id})[6];
			my $Viti_vi_seq=(split /\s+/, $Viti_vi{$id})[6];
			my $Sola_tu_seq=(split /\s+/, $Sola_tu{$id})[6];
			my $Oryza_brach_seq=(split /\s+/, $Oryza_brach{$id})[6];
			my $Brach_seq=(split /\s+/, $Brach{$id})[6];
			my $Seta_ti_seq=(split /\s+/, $Seta_ti{$id})[6];
			my $seqs_identity=&seq2identity($Cucumber_seq, $Cucu_melo_seq, $Water_melo_seq,$Malus_dome_seq,$Glyc_max_seq,$Popu_tr_seq,$Citrus_seq,$Brass_ra_seq,$Arab_ly_seq,$Arab_ly_seq,$Viti_vi_seq,$Sola_tu_seq,$Oryza_brach_seq,$Brach_seq,$Seta_ti_seq);
			my $tmp=$Cucumber_seq;$tmp=~s/\-//g;
			my $ref_seq_len=length($tmp);
	#############################
	#Out put the maf+identitiy ##
	#############################
  	#&print_maf_identity($id,$seqs_identity);

	#############################
	#Out put the maf files     ##
	#############################
  	if ( ($seqs_identity >= $identity_cut) and ($ref_seq_len >= $len_cut) ){
  		if ($out_label == 1){
				print "$maf_hash{$id}\n\n";
			}elsif($out_label == 2){
				my $line=&maf2fasta($maf_hash{$id},$id);
				print "$line";
			}elsif($out_label == 3){
				my $line=&maf2table($maf_hash{$id},$id);
				print "$line";
			}
		
		}
	}
}



sub print_maf_identity {
	my ($maf_id, $identity)=@_;
	my @all=split /\n/, $maf_hash{$maf_id};
	foreach my $i(@all){
		print "$i\t$identity\n";
	}
	print "\n";
}


sub maf2fasta{
	my($line,$id)=@_;
	my @all=split /\n/,$line;
	foreach (@all){
		if (!/score/){
			my @bll=split /\s+/, $_;
			my ($t,$chr,$start,$len,$strand,$total,$seq)=@bll;
			$seq=~s/\-//g;
			print ">MAAs_$id\|$chr|$start\|$len\|$strand\n$seq\n";
		}
	}
}

sub maf2table{
	my($line,$id)=@_;
	my @all=split /\n/,$line;
	foreach (@all){
		if (!/score/){
			my @bll=split /\s+/, $_;
			my ($t,$chr,$start,$len,$strand,$total,$seq)=@bll;
			my ($spec)=(split /\./, $chr)[0]; 
			my $scaffold;
			if ($chr =~ /\|/){
				($scaffold)=(split /\|/, $chr)[3];
			}else{
				($scaffold)=(split /\./, $chr)[1];
			}
			my $end=($start+$len-1);
			print "$id\t$spec\t$scaffold\t$start\t$end\t$strand\t$seq\n";
		}
	}
}

sub seq2identity {
	######################################################
	# Calculate the seqs' identity with cucumber as ref ##
	######################################################
	my ($ref_seq, $seq1, $seq2, $seq3, $seq4, $seq5,$seq6,$seq7,$seq8,$seq9,$seq10,$seq11,$seq12,$seq13, $seq14)=@_;
	my @ref=split //, $ref_seq;
	my @seq1=split //, $seq1;
	my @seq2=split //, $seq2;
	my @seq3=split //, $seq3;
	my @seq4=split //, $seq4;
	my @seq5=split //, $seq5;
	my @seq6=split //, $seq6;
	my @seq7=split //, $seq7;
	my @seq8=split //, $seq8;
	my @seq9=split //, $seq9;
	my @seq10=split //, $seq10;
	my @seq11=split //, $seq11;
	my @seq12=split //, $seq12;
	my @seq13=split //, $seq13;
	my @seq14=split //, $seq14;
	my $num=0;### record the loc which are the same base in n seqs
	my $len=scalar(@ref);
   	for (my $i=0; $i < $len; $i++){
		if (($ref[$i] eq $seq1[$i]) and ($ref[$i] eq $seq2[$i]) and ($ref[$i] eq $seq3[$i]) and ($ref[$i] eq $seq4[$i]) and ($ref[$i] eq $seq5[$i]) and ($ref[$i] eq $seq6[$i]) and ($ref[$i] eq $seq7[$i]) and ($ref[$i] eq $seq8[$i]) and ($ref[$i] eq $seq9[$i]) and ($ref[$i] eq $seq10[$i]) and ($ref[$i] eq $seq11[$i]) and ($ref[$i] eq $seq12[$i]) and ($ref[$i] eq $seq13[$i]) and ($ref[$i] eq $seq14[$i])){
	   $num++;
	   }
	}
	return ($num/$len);
}



sub collect_spec_hash{
	my ($maf_hash)=@_;
	foreach (keys%$maf_hash){
		my @all=split /\n/, $maf_hash{$_};
		foreach my $i(@all){
			if ($i =~ /Cucumber/){
				$Cucumber{$_}=$i;
			}elsif ($i =~ /Cucu-me/){
				$Cucu_melo{$_}=$i;
			}elsif ($i =~ /Water/){
				$Water_melo{$_}=$i;
			}elsif ($i =~ /Malus-dome/){
				$Malus_dome{$_}=$i;
			}elsif ($i =~ /Glyc-max/){
				$Glyc_max{$_}=$i;
			}elsif ($i =~ /Popu-tr/){
				$Popu_tr{$_}=$i;
			}elsif ($i =~ /Citrus/){
				$Citrus{$_}=$i;
			}elsif ($i =~ /Brass-ra/){
				$Brass_ra{$_}=$i;
			}elsif ($i =~ /Arab-ly/){
				$Arab_ly{$_}=$i;
			}elsif ($i =~ /Arab-th/){
				$Arab_th{$_}=$i;
			}elsif ($i =~ /Viti-vi/){
				$Viti_vi{$_}=$i;
			}elsif ($i =~ /Sola-tu/){
				$Sola_tu{$_}=$i;
			}elsif ($i =~ /Oryza-brach/){
				$Oryza_brach{$_}=$i;
			}elsif ($i =~ /Brach/){
				$Brach{$_}=$i;
			}elsif ($i =~ /Seta-ti/){
				$Seta_ti{$_}=$i;
				}
    		}
		}
	}



sub collect_maf_hash{
	my ($file)=@_;
	open IN, $file;
	my @all=<IN>;
	my $a=join "", @all;
	my @all_elements=split /\n\n/, $a;
	my $index=1;
	foreach my $i(@all_elements){
			my @lines;
			my @all=split /\n/,$i;
			foreach my $j(@all){
      			if ($j =~ /^s/){
	  				push @lines, $j;
      			}
   			}
   	my $total=join "\n", @lines;
	$maf_hash{$index}=$total;
	$index++;
	}
	close IN;
}
