# Author by songht.CMB.bnu 
# Date: 2017-12-01
#!/bin/sh
export perl="/userset/perl"



##############################################################################################
# Prepare dataset: 12way.multiz produced by alignment.sh, 12 species.list					 
# Description: Step 1 From 12-way multiple alignment file, using mafTool-master tool to select
#              subgroup of n species which coexisted in one aligned block and saved as    	 
#              n-way multiple alignment anchors [n-way.MAAs]						          
#              From 1.1 to 1.14 step by step												 
# Usage:Species indexed by d, where d is gradually increased with the divergence from        
#       cucumber according to the phylogenetic tree in Figure 1                              
#       Dependency_tools: mafTool-master										             	
#       Input: 15way.multiz,12 species.list				     								  
#       Output: n-way.MAAs [n=1~12]								             				 
##############################################################################################
export mafTools-master="/Userset/mafTools-master/bin"
export MAAs_files="/Userset/MAAs_files"
spec1='melo'
spec2='watermelo'
spec3='bottlegourd'
spec4='waxgourd'
spec5='pepo'
spec6='Cmoschata'
spec7='Cargyros'
spec8='Cmaxima'
spec9='spongegourd'
spec10='chayote'
spec11='snakegourd'
spec12='bittergourd'
minWidth=20

$multiz M=$minWidth ${ref}_${spec1}.maf ${ref}_${spec2}.maf 1 > 3way.maf
$multiz M=$minWidth 3way.maf ${ref}_${spec3}.maf 1 > 4way.maf
$multiz M=$minWidth 4way.maf ${ref}_${spec4}.maf 1 > 5way.maf
$multiz M=$minWidth 5way.maf ${ref}_${spec5}.maf 1 > 6way.maf
$multiz M=$minWidth 6way.maf ${ref}_${spec6}.maf 1 > 7way.maf
$multiz M=$minWidth 7way.maf ${ref}_${spec7}.maf 1 > 8way.maf
$multiz M=$minWidth 8way.maf ${ref}_${spec8}.maf 1 > 9way.maf
$multiz M=$minWidth 9way.maf ${ref}_${spec9}.maf 1 > 10way.maf
$multiz M=$minWidth 10way.maf ${ref}_${spec10}.maf 1 > 11way.maf
$multiz M=$minWidth 11way.maf ${ref}_${spec11}.maf 1 > 12way.maf
$multiz M=$minWidth 12way.maf ${ref}_${spec12}.maf 1 > 13way.maf

#test remove snakegourd genome due to its bad alignment#
$multiz M=$minWidth 11way.maf ${ref}_${spec12}.maf 1 > 12way-2.maf

#-------------mafFilter for 13way alignment--------------------------#
mafFilter -minCol=20 -minRow=12 12way-2.maf > good.maf



#################################################################################################################
# Prepare dataset: good.maf    															 					
# Description: Step 2 From MAAs-12 multiple alignment file, using in-house perl script to        				
# 	select MAAs according to its identity and length							                        
# Usage: perl maf_parse.pl identity_cut length_cut output_label <1: output_fasta; 2: output_table>		
#	identity_cut: Indicating a [0,1] number which determines the at least ratio of identical bases		
#		accross all 12 species in one block with cucucmber as reference. Default: 0 			
#	length_cut: Indicating the minial length of blocks with cucumber as reference. Default: 1				
#	output_label: 1:len_identity.maf, 2:len_identity.fasta, 3:len_identity.table							
#		Columns in table: MAAs-ID species chromosome start end strand aligned_seq\n";		    	            
#	Input: good.maf								     								 				
#	Output: MAAs.fasta or MAAs.table or MAAs.maf 							             					
#################################################################################################################
export good.maf="/Userset/good.maf"
export pl_scripts="/Userset/pl_scripts"
export identity_cut="0"
export length_cut="1"
export output="/Userset/Output"

echo 'Step2.1 MAAs.table start at'
export $out_label="3"
date
perl ${pl_scripts}/maf_parse.pl ${MAAs-15.maf} $identity_cut $length_cut $out_label > $output/MAAs.table 
echo 'Step2.1 finished at'
date

echo 'Step2.2 MAAs.maf start at'
export $out_label="1"
date
perl ${pl_scripts}/maf_parse.pl ${MAAs-15.maf} $identity_cut $length_cut $out_label > $output/MAAs.maf 
echo 'Step2.2 finished at'
date

echo 'Step2.3 MAAs.fasta start at'
export $out_label="2"
date
perl ${pl_scripts}/maf_parse.pl ${MAAs-15.maf} $identity_cut $length_cut $out_label > $output/MAAs.fasta 
echo 'Step2.3 finished at'
date







